@@ -33,7 +33,6 @@ from wagtail.admin.panels import (
     FieldPanel,
     MultiFieldPanel,
     ObjectList,
-    StreamFieldPanel,
     TabbedInterface,
 )
 from wagtail.core import hooks
@@ -80,6 +79,8 @@ def get_page_models():
 class CjkcmsPageMeta(PageBase):
     def __init__(cls, name, bases, dct):
         super().__init__(name, bases, dct)
+        if "search_template" not in dct:
+            cls.search_template = "cjkcms/pages/search_result.html"
         if not cls._meta.abstract:  # type: ignore
             CJKCMS_PAGE_MODELS.append(cls)
 
@@ -280,11 +281,8 @@ class CjkcmsPage(WagtailCacheMixin, SeoMixin, Page, metaclass=CjkcmsPageMeta):
             self.index_order_by = self.index_order_by_default
             self.index_show_subpages = self.index_show_subpages_default
 
-    @cached_classmethod
-    def get_edit_handler(cls):  # sourcery skip: instance-method-first-arg-name
-        """
-        Override to "lazy load" the panels overridden by subclasses.
-        """
+    @classmethod
+    def get_panels(cls):  # sourcery skip: instance-method-first-arg-name
         panels = [
             ObjectList(
                 cls.content_panels
@@ -308,7 +306,17 @@ class CjkcmsPage(WagtailCacheMixin, SeoMixin, Page, metaclass=CjkcmsPageMeta):
                     classname="integrations",
                 )
             )
+        print("Got panels...")
+        return panels
 
+    @cached_classmethod
+    def get_edit_handler(cls):  # sourcery skip: instance-method-first-arg-name
+        """
+        Override to "lazy load" the panels overridden by subclasses.
+        """
+        print("getting panels...")
+        panels = cls.get_panels()  # override e.g. by appending new panels
+        print(panels)
         edit_handler = TabbedInterface(panels)
         return edit_handler.bind_to_model(cls)
 
@@ -470,7 +478,7 @@ class CjkcmsWebPage(CjkcmsPage):
 
     # Panels
     body_content_panels = [
-        StreamFieldPanel("body"),
+        FieldPanel("body"),
     ]
 
     @property
